/****************************************
* Reception et afficahge des donnees de capteurs
* Module 12 entrees analogiques / 16 numériques vers Midi
* Interface-Z
* Sensors data reception and display from
* 12 analogical ways / 16 digital ways to Midi
*****************************************/

import rwmidi.*;
// RWMidi se trouve chez http://ruinwesen.com/blog?id=95

MidiInput input;

void setup() {
  size(320, 200);
  smooth();
  noStroke();
  background(0);

  // Affichage des peripheriques Midi disponibles  
    // Displaying Midi devices existing on the computer  
  println("........Peripheriques Midi In........");
  println(RWMidi.getInputDevices());

  // Choisir le numero du peripherique dans la liste
  // Ce numero, ici [1] correspond au port Midi utilise par la carte.
    // Choose the appropriate Midi device from the list
  input = RWMidi.getInputDevices()[1].createInput(this);

  PFont fontA = loadFont("CourierNew-12.vlw");
  textFont(fontA, 12);

}

// Reception des capteurs tout ou rien
// Receiving "all or nothing" sensors
int[] inter = new int[16];
int pitch;

void noteOnReceived(Note note) {
  pitch = note.getPitch();
  if ((pitch>=0)&&(pitch<16)) {  
    inter[pitch] = note.getVelocity(); 
    println("Note On " + pitch + " " + inter[pitch]);
  }
}

// Reception des capteurs analogiques
// Receiving analogical sensors
int[] valeur = new int[12];
int numero;

void controllerChangeReceived(Controller ctlchg) {
  numero = ctlchg.getCC();
  if ((numero<40)&&(numero>31)) {
    numero = numero-32;  
    valeur[numero] = ctlchg.getValue();
    println("Capteur n°" + (numero+1) + " " + valeur[numero]);
  }
    if ((numero<52)&&(numero>47)) {
    numero = numero-40;  
    valeur[numero] = ctlchg.getValue();
    println("Capteur n°" + (numero+1) + " " + valeur[numero]);
  }
}


void draw() {
  fill(255);
  text("12 Analogiques / 16 Numeriques Midi", 10, 30);

  // Affichage des entrees numeriques
  // Displaying digital ways
  
  // Carres roses 8/8
  fill(255, 70, 200);
  for(int i=0; i<8; i++) {
    rect(260, 12+(i*20), 16, 16);
    // Numeros des interrupteurs
    text(i, 280, 24+(i*20));
  }
  for(int i=0; i<8; i++) {
    // Opacite 0 quand interrupteur inactif
    fill(255,190,200,inter[i]*4);
    rect(262, 14+(i*20), 12, 12);
  } 

  // Carres bleus 4/8
  fill(0, 70, 200);
  for(int i=0; i<8; i++) {
    rect(290, 12+(i*20), 16, 16);
    // Numeros des interrupteurs
    text(i, 310, 24+(i*20));
  }
  for(int i=0; i<8; i++) {
    // Opacite 0 quand interrupteur inactif
    fill(0,190,200,inter[i+8]*4);
    rect(292, 14+(i*20), 12, 12);
  } 


  // Affichage des entrees analogiques
  // Displaying analogical ways
  
  // Blocs roses 8/8
  fill(250, 0, 255);
  for(int i=0; i<8; i++) {
    rect(14+(i*20), 40, 16, 128);
    // Numeros des capteurs
    text(i+1, 19+(i*20), 185);
  }
  // Curseur dependant du capteur
  fill(250,190,255);
  for(int i=0; i<8; i++) {
    rect(14+(i*20), 167-valeur[i], 16, valeur[i]);
  }  
  
    // Blocs bleus 4/8
  fill(0, 0, 255);
  for(int i=0; i<4; i++) {
    rect(174+(i*20), 40, 16, 128);
    // Numeros des capteurs
    text(i+1, 179+(i*20), 185);
  }
  // Curseur dependant du capteur
  fill(0,190,255);
  for(int i=0; i<4; i++) {
    rect(174+(i*20), 167-valeur[i], 16, valeur[i]);
  }  
  
}



